@@ -173,7 +173,7 @@ void KSldApp::initialize()
         a->setObjectName(QStringLiteral("Lock Session"));
         a->setProperty("componentName", QStringLiteral("ksmserver"));
         a->setText(i18n("Lock Session"));
-        KGlobalAccel::self()->setGlobalShortcut(a, QList<QKeySequence>() << Qt::META+Qt::Key_L << Qt::ALT+Qt::CTRL+Qt::Key_L << Qt::Key_ScreenSaver );
+        KGlobalAccel::self()->setGlobalShortcut(a, KScreenSaverSettings::defaultShortcuts());
         connect(a, &QAction::triggered, this,
             [this]() {
                 lock(EstablishLock::Immediate);
@@ -234,7 +234,7 @@ void KSldApp::initialize()
             }
         }
     );
-    connect(m_lockProcess, static_cast<void (QProcess::*)(QProcess::ProcessError)>(&QProcess::error), this,
+    connect(m_lockProcess, &QProcess::errorOccurred, this,
         [this](QProcess::ProcessError error) {
             if (error == QProcess::FailedToStart) {
                 doUnlock();
@@ -281,7 +281,7 @@ void KSldApp::initialize()
     );
     connect(m_logind, &LogindIntegration::inhibited, this,
         [this]() {
-            // if we are already locked, we immediatelly remove the inhibition lock
+            // if we are already locked, we immediately remove the inhibition lock
             if (m_lockState == KSldApp::Locked) {
                 m_logind->uninhibit();
             }
@@ -566,7 +566,7 @@ void KSldApp::startLockProcess(EstablishLock establishLock)
         int sx[2];
         if (socketpair(AF_UNIX, SOCK_STREAM | SOCK_CLOEXEC, 0, sx) < 0) {
             qWarning() << "Can not create socket";
-            emit m_lockProcess->error(QProcess::FailedToStart);
+            emit m_lockProcess->errorOccurred(QProcess::FailedToStart);
             return;
         }
         m_greeterClientConnection = m_waylandDisplay->createClient(sx[0]);
@@ -608,7 +608,7 @@ void KSldApp::startLockProcess(EstablishLock establishLock)
     // start the Wayland server
     int fd = m_waylandServer->start();
     if (fd == -1) {
-        emit m_lockProcess->error(QProcess::FailedToStart);
+        emit m_lockProcess->errorOccurred(QProcess::FailedToStart);
         return;
     }
 
